import 'package:senior_platform_authentication/senior_platform_authentication.dart';

import '../../data/repositories/secure_storage_repository.dart';
import '../entities/user_name.dart';

/// Get current token on local storage.
///
/// This usecase does not syncronize the token local data with remote data.
/// Use it to get the token that is saved on local storage.
class GetStoredTokenUsecase implements BaseUsecase<Token?, UserName> {
  late final SecureStorageRepository _secureStorageRepository;

  GetStoredTokenUsecase({
    SecureStorageRepository? secureStorageRepository,
  }) {
    _secureStorageRepository =
        secureStorageRepository ?? SecureStorageRepositoryImpl();
  }

  @override
  Future<Token?> call(UserName username) async {
    final currentUsername = username.currentUsername?.isEmpty ?? true
        ? await _secureStorageRepository.readLastUser() ?? ''
        : username.currentUsername!;
    return await _secureStorageRepository.readToken(username: currentUsername);
  }
}
