import 'package:senior_platform_authentication/senior_platform_authentication.dart';

import '../../data/repositories/secure_storage_repository.dart';
import '../entities/user_name.dart';

/// Get current user on local storage.
///
/// This usecase does not syncronize the user local data with remote data.
/// Use it to get the user that is saved on local storage.
class GetStoredUserUsecase implements BaseUsecase<User?, UserName> {
  late final SecureStorageRepository _secureStorageRepository;

  GetStoredUserUsecase({
    SecureStorageRepository? secureStorageRepository,
  }) {
    _secureStorageRepository =
        secureStorageRepository ?? SecureStorageRepositoryImpl();
  }

  @override
  Future<User?> call(UserName username) async {
    final currentUsername = username.currentUsername?.isEmpty ?? true
        ? await _secureStorageRepository.readLastUser() ?? ''
        : username.currentUsername!;
    return await _secureStorageRepository.readUser(
      username: currentUsername,
    );
  }
}
