part of 'authentication_bloc.dart';

/// Base authentication event class.
abstract class AuthenticationEvent extends Equatable {
  const AuthenticationEvent();
}

/// Fired everytime user's authentication status changes.
class AuthenticationStatusChanged extends AuthenticationEvent {
  /// Current user's authentication status.
  final AuthenticationStatus status;

  /// Authentication response must be passed when the status is
  /// [AuthenticationStatus.authenticated].
  final AuthenticationResponse? authenticationResponse;

  const AuthenticationStatusChanged(this.status, {this.authenticationResponse});

  @override
  List<Object?> get props => [
        status,
        authenticationResponse,
      ];
}

/// Calls logout when login offline is disabled.
class LogoutOnlineRequested extends AuthenticationEvent {
  const LogoutOnlineRequested();

  @override
  List<Object?> get props => [];
}

/// Calls logout when login offline is enabled.
class LogoutOfflineRequested extends AuthenticationEvent {
  /// Current username saved on storage.
  final String username;

  /// Flag that erase token from sotrage.
  final bool eraseToken;

  const LogoutOfflineRequested({
    required this.username,
    this.eraseToken = false,
  });

  @override
  List<Object?> get props => [
        username,
        eraseToken,
      ];
}

/// Check if the user has a valid authentication.
///
/// You must call this event as soon as you instantiate the authentication bloc
/// for the provider. See the documentation with examples for more details.
class CheckAuthenticationRequested extends AuthenticationEvent {
  /// Current username saved on storage.
  final String? username;

  const CheckAuthenticationRequested({
    this.username,
  });

  @override
  List<Object?> get props => [
        username,
      ];
}
