part of 'authentication_bloc.dart';

class AuthenticationState extends Equatable {
  /// Current authentication status
  ///
  /// Default value is [AuthenticationStatus.unknown] when app is initializing.
  final AuthenticationStatus status;

  /// Current username saved on memory.
  final String? username;

  const AuthenticationState._({
    this.status = AuthenticationStatus.unknown,
    this.username,
  });

  /// Unkown authentication state.
  ///
  /// It means that the application doesn't know yet the status of authentication.
  const AuthenticationState.unknown() : this._();

  /// Authenticated authentication state.
  ///
  /// The state that is emitted when the authentication status changed to
  /// authenticated.
  const AuthenticationState.authenticated({String? username})
      : this._(
          status: AuthenticationStatus.authenticated,
          username: username,
        );

  /// Unauthenticated authentication state.
  ///
  /// The state that is emitted when the authentication status changed to
  /// unauthenticated.
  const AuthenticationState.unauthenticated()
      : this._(
          status: AuthenticationStatus.unauthenticated,
          username: null,
        );

  /// Offline authentication state.
  ///
  /// The state that is emitted when the connection to network is lost.
  const AuthenticationState.offline(String username)
      : this._(
          status: AuthenticationStatus.offline,
          username: username,
        );

  @override
  List<Object?> get props => [
        status,
        username,
      ];
}
